@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 
 __author__ = 'Markus Holtermann'
-__email__ = 'info@sinnwerkstatt.com'
-__version__ = '0.3.2'
+__email__ = 'info@markusholtermann.eu'
+__version__ = '0.3.3'
 
 default_app_config = 'dynamic_forms.apps.DynamicFormsConfig'
